@@ -248,7 +248,6 @@ def __write_function(
         micro_batch_df.alias(micro_batch_df_name), upsert_condition
     ).whenMatchedUpdateAll(match_condition).whenNotMatchedInsertAll().execute()
 
-    spark.sql(f"ALTER TABLE {table_name} OWNER TO `data-platform`")
     print(f"Created table {table_name} and loaded data")
 
     return True
@@ -329,17 +328,37 @@ def write_table(
     )
 
 
-def __apply_profiling(df: DataFrame, profiling_s3_bucket, profiling_s3_key):
+def __apply_profiling(df: DataFrame, profiling_s3_bucket, profiling_s3_key, layer: str):
     if df.count() == 0:
         raise ValueError("Dataframe is empty, profile aborted")
     else:
-        profile_js = calculate_profilling(df)
+        profile_js = calculate_profilling(df, layer)
         profile_js = json.dumps(profile_js)
         s3_client = S3(bucket_name=profiling_s3_bucket)
 
+        __save_database_profile(profile_js, layer)
+
         return s3_client.put_object(profile_js, s3_key=profiling_s3_key)
 
 
+def __save_database_profile(profile_js, layer):
+    if layer == "bronze":
+        table = "cortex.data_governance_quality.bronze_profile"
+    elif layer == "silver":
+        table = "cortex.data_governance_quality.silver_profile"
+    else:
+        table = "cortex.data_governance_quality.gold_profile"
+
+    fields = profile_js["profilling"]["descriptiveStatistics"]["fields"]
+    df_default = spark.createDataFrame(pd.json_normalize(fields))
+    df_default.write.option("header", "true").format('delta').mode('append').option("mergeSchema","true").saveAsTable(table)
+
+    # if layer == "bronze":
+    #     frequent_fields = profile_js["profilling"]["descriptiveStatistics"]["mostFrequentFields"]
+    #     df_frequent = spark.createDataFrame(pd.json_normalize(frequent_fields))
+    #     df_frequent.write.option("header", "true").format('delta').mode('append').option("mergeSchema", "true").saveAsTable(table)
+
+
 def __apply_processing_function(
     df: DataFrame, func: Callable, args: list, kwargs: dict
 ):
@@ -376,15 +395,33 @@ def apply_processing_function(df: DataFrame, func, func_args, func_kwargs):
             df=df, func=func, args=func_args, kwargs=func_kwargs
         )
 
+# função que grava as métricas de qualidade no databricks
+def save_database_profile_history(quality_js, profiling_s3_bucket):
+    if profiling_s3_bucket.find("bronze") >= 0:
+        table = "cortex.data_governance_quality.bronze_profile_history"
+    elif profiling_s3_bucket.find("silver") >= 0:
+        table = "cortex.data_governance_quality.silver_profile_history"
+    else:
+        table = "cortex.data_governance_quality.gold_profile_history"
+        
+    fields=quality_js["profilling"]["descriptiveStatistics"]["fields"]
+    df = spark.createDataFrame(pd.json_normalize(fields))
+    df.write.option("header", "true").format('delta').mode('append').option("mergeSchema", "true").saveAsTable(table)
 
-def apply_profiling(df: DataFrame, data_pack_name: str, dataset_name: str):
+    # if profiling_s3_bucket.find("bronze") >= 0:
+    #     frequent_fields=quality_js["profilling"]["descriptiveStatistics"]["mostFrequentFields"]
+    #     df = spark.createDataFrame(pd.json_normalize(frequent_fields))
+    #     df.write.option("header", "true").format('delta').mode('append').option("mergeSchema", "true").saveAsTable(table)
+
+
+def apply_profiling(df: DataFrame, data_pack_name: str, dataset_name: str, layer: str):
     # TODO: PARTICIONAR POR DATA
     profiling_s3_key = f"_databricks_profiling/{data_pack_name}/{dataset_name}.json"
     print(f"START PROFILING: {profiling_s3_key}")
     df.printSchema()
     df.show(5)
     __apply_profiling(
-        df=df, profiling_s3_bucket=BRONZE_BUCKET, profiling_s3_key=profiling_s3_key
+        df=df, profiling_s3_bucket=BRONZE_BUCKET, profiling_s3_key=profiling_s3_key, layer=layer
     )
 
     return True
@@ -533,7 +570,9 @@ def landing_to_bronze(
     if profiling:
         stream.awaitTermination()
         df = spark.read.table(db_table)
-        apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
+        apply_profiling(
+            df=df, data_pack_name=data_pack_name, dataset_name=dataset_name, layer="bronze"
+        )
 
     return True
 
@@ -634,7 +673,9 @@ def bronze_to_silver(
     if profiling:
         stream.awaitTermination()
         df = spark.read.table(output_db_table)
-        apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
+        apply_profiling(
+            df=df, data_pack_name=data_pack_name, dataset_name=dataset_name, layer="silver"
+        )
 
     return True
 
@@ -735,7 +776,9 @@ def silver_to_gold(
     if profiling:
         stream.awaitTermination()
         df = spark.read.table(output_db_table)
-        apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
+        apply_profiling(
+            df=df, data_pack_name=data_pack_name, dataset_name=dataset_name, layer="gold"
+        )
 
 
 def gold_to_kafka(
